==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/labservices/kotlin/inputs/RosterProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.labservices.kotlin.inputs

import com.pulumi.azurenative.labservices.inputs.RosterProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The lab user list management profile.
 * @property activeDirectoryGroupId The AAD group ID which this lab roster is populated from. Having this set enables AAD sync mode.
 * @property lmsInstance The base URI identifying the lms instance.
 * @property ltiClientId The unique id of the azure lab services tool in the lms.
 * @property ltiContextId The unique context identifier for the lab in the lms.
 * @property ltiRosterEndpoint The uri of the names and roles service endpoint on the lms for the class attached to this lab.
 */
public data class RosterProfileArgs(
    public val activeDirectoryGroupId: Output<String>? = null,
    public val lmsInstance: Output<String>? = null,
    public val ltiClientId: Output<String>? = null,
    public val ltiContextId: Output<String>? = null,
    public val ltiRosterEndpoint: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.labservices.inputs.RosterProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.labservices.inputs.RosterProfileArgs =
        com.pulumi.azurenative.labservices.inputs.RosterProfileArgs.builder()
            .activeDirectoryGroupId(activeDirectoryGroupId?.applyValue({ args0 -> args0 }))
            .lmsInstance(lmsInstance?.applyValue({ args0 -> args0 }))
            .ltiClientId(ltiClientId?.applyValue({ args0 -> args0 }))
            .ltiContextId(ltiContextId?.applyValue({ args0 -> args0 }))
            .ltiRosterEndpoint(ltiRosterEndpoint?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RosterProfileArgs].
 */
@PulumiTagMarker
public class RosterProfileArgsBuilder internal constructor() {
    private var activeDirectoryGroupId: Output<String>? = null

    private var lmsInstance: Output<String>? = null

    private var ltiClientId: Output<String>? = null

    private var ltiContextId: Output<String>? = null

    private var ltiRosterEndpoint: Output<String>? = null

    /**
     * @param value The AAD group ID which this lab roster is populated from. Having this set enables AAD sync mode.
     */
    @JvmName("hxtmdsrlbfvsgikp")
    public suspend fun activeDirectoryGroupId(`value`: Output<String>) {
        this.activeDirectoryGroupId = value
    }

    /**
     * @param value The base URI identifying the lms instance.
     */
    @JvmName("citvjaebwtmwaqbp")
    public suspend fun lmsInstance(`value`: Output<String>) {
        this.lmsInstance = value
    }

    /**
     * @param value The unique id of the azure lab services tool in the lms.
     */
    @JvmName("lgvqqcrcmrvbxrqx")
    public suspend fun ltiClientId(`value`: Output<String>) {
        this.ltiClientId = value
    }

    /**
     * @param value The unique context identifier for the lab in the lms.
     */
    @JvmName("qbvegaoykwjmbqrt")
    public suspend fun ltiContextId(`value`: Output<String>) {
        this.ltiContextId = value
    }

    /**
     * @param value The uri of the names and roles service endpoint on the lms for the class attached to this lab.
     */
    @JvmName("bnjqhhmvvprdmxan")
    public suspend fun ltiRosterEndpoint(`value`: Output<String>) {
        this.ltiRosterEndpoint = value
    }

    /**
     * @param value The AAD group ID which this lab roster is populated from. Having this set enables AAD sync mode.
     */
    @JvmName("pvlmajnxqenjakig")
    public suspend fun activeDirectoryGroupId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.activeDirectoryGroupId = mapped
    }

    /**
     * @param value The base URI identifying the lms instance.
     */
    @JvmName("kpmgdteodgyhtfvh")
    public suspend fun lmsInstance(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lmsInstance = mapped
    }

    /**
     * @param value The unique id of the azure lab services tool in the lms.
     */
    @JvmName("rnndgdwuswilpfwo")
    public suspend fun ltiClientId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ltiClientId = mapped
    }

    /**
     * @param value The unique context identifier for the lab in the lms.
     */
    @JvmName("qnofpbgsiddeeuar")
    public suspend fun ltiContextId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ltiContextId = mapped
    }

    /**
     * @param value The uri of the names and roles service endpoint on the lms for the class attached to this lab.
     */
    @JvmName("itwkyccvdmopqhyf")
    public suspend fun ltiRosterEndpoint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ltiRosterEndpoint = mapped
    }

    internal fun build(): RosterProfileArgs = RosterProfileArgs(
        activeDirectoryGroupId = activeDirectoryGroupId,
        lmsInstance = lmsInstance,
        ltiClientId = ltiClientId,
        ltiContextId = ltiContextId,
        ltiRosterEndpoint = ltiRosterEndpoint,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/labservices/kotlin/inputs/RosterProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.labservices.kotlin.inputs

import com.pulumi.azurenative.labservices.inputs.RosterProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The lab user list management profile.
 * @property activeDirectoryGroupId The AAD group ID which this lab roster is populated from. Having this set enables AAD sync mode.
 * @property lmsInstance The base URI identifying the lms instance.
 * @property ltiClientId The unique id of the azure lab services tool in the lms.
 * @property ltiContextId The unique context identifier for the lab in the lms.
 * @property ltiRosterEndpoint The uri of the names and roles service endpoint on the lms for the class attached to this lab.
 */
public data class RosterProfileArgs(
    public val activeDirectoryGroupId: Output<String>? = null,
    public val lmsInstance: Output<String>? = null,
    public val ltiClientId: Output<String>? = null,
    public val ltiContextId: Output<String>? = null,
    public val ltiRosterEndpoint: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.labservices.inputs.RosterProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.labservices.inputs.RosterProfileArgs =
        com.pulumi.azurenative.labservices.inputs.RosterProfileArgs.builder()
            .activeDirectoryGroupId(activeDirectoryGroupId?.applyValue({ args0 -> args0 }))
            .lmsInstance(lmsInstance?.applyValue({ args0 -> args0 }))
            .ltiClientId(ltiClientId?.applyValue({ args0 -> args0 }))
            .ltiContextId(ltiContextId?.applyValue({ args0 -> args0 }))
            .ltiRosterEndpoint(ltiRosterEndpoint?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RosterProfileArgs].
 */
@PulumiTagMarker
public class RosterProfileArgsBuilder internal constructor() {
    private var activeDirectoryGroupId: Output<String>? = null

    private var lmsInstance: Output<String>? = null

    private var ltiClientId: Output<String>? = null

    private var ltiContextId: Output<String>? = null

    private var ltiRosterEndpoint: Output<String>? = null

    /**
     * @param value The AAD group ID which this lab roster is populated from. Having this set enables AAD sync mode.
     */
    @JvmName("wrxbcdjgwwhbxybj")
    public suspend fun activeDirectoryGroupId(`value`: Output<String>) {
        this.activeDirectoryGroupId = value
    }

    /**
     * @param value The base URI identifying the lms instance.
     */
    @JvmName("biaiddhjkxlowqvi")
    public suspend fun lmsInstance(`value`: Output<String>) {
        this.lmsInstance = value
    }

    /**
     * @param value The unique id of the azure lab services tool in the lms.
     */
    @JvmName("mparumeviofswecn")
    public suspend fun ltiClientId(`value`: Output<String>) {
        this.ltiClientId = value
    }

    /**
     * @param value The unique context identifier for the lab in the lms.
     */
    @JvmName("rwdtyfsnlfvvajua")
    public suspend fun ltiContextId(`value`: Output<String>) {
        this.ltiContextId = value
    }

    /**
     * @param value The uri of the names and roles service endpoint on the lms for the class attached to this lab.
     */
    @JvmName("wapclyxdbgdkoike")
    public suspend fun ltiRosterEndpoint(`value`: Output<String>) {
        this.ltiRosterEndpoint = value
    }

    /**
     * @param value The AAD group ID which this lab roster is populated from. Having this set enables AAD sync mode.
     */
    @JvmName("krgiypcvmfdaydci")
    public suspend fun activeDirectoryGroupId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.activeDirectoryGroupId = mapped
    }

    /**
     * @param value The base URI identifying the lms instance.
     */
    @JvmName("lrtdsldidjdcimih")
    public suspend fun lmsInstance(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lmsInstance = mapped
    }

    /**
     * @param value The unique id of the azure lab services tool in the lms.
     */
    @JvmName("mfwfatksasyqsgwg")
    public suspend fun ltiClientId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ltiClientId = mapped
    }

    /**
     * @param value The unique context identifier for the lab in the lms.
     */
    @JvmName("aldfvnvkxuovmrmo")
    public suspend fun ltiContextId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ltiContextId = mapped
    }

    /**
     * @param value The uri of the names and roles service endpoint on the lms for the class attached to this lab.
     */
    @JvmName("esdiibdxaqwdwyvb")
    public suspend fun ltiRosterEndpoint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ltiRosterEndpoint = mapped
    }

    internal fun build(): RosterProfileArgs = RosterProfileArgs(
        activeDirectoryGroupId = activeDirectoryGroupId,
        lmsInstance = lmsInstance,
        ltiClientId = ltiClientId,
        ltiContextId = ltiContextId,
        ltiRosterEndpoint = ltiRosterEndpoint,
    )
}
